@@ -1089,15 +1089,18 @@ class NYSEExchangeCalendar(MarketCalendar):
         :param tz: time zone in either string or pytz.timezone
         :return: DatetimeIndex of valid business days
         """
-        trading_days = super().valid_days(start_date, end_date, tz= 'UTC')
+        trading_days = super().valid_days(start_date, end_date, tz= tz)
 
         # Starting Monday Sept. 29, 1952, no more saturday trading days
-        above_cut_off = trading_days >= self._saturday_end
+        if tz is None: saturday_end = self._saturday_end.tz_localize(None)
+        else: saturday_end = self._saturday_end
+
+        above_cut_off = trading_days >= saturday_end
         if above_cut_off.any():
             above_and_saturday = (trading_days.weekday == 5) & above_cut_off
             trading_days = trading_days[~above_and_saturday]
 
-        return trading_days.tz_convert(tz)
+        return trading_days
 
 
     def days_at_time(self, days, market_time, day_offset=0):
